@@ -16,7 +16,7 @@ class CompensationEndEvent(BpmnNode):
 
     def execute(self, state: State, environment: Environment) -> Tuple[State, Actions]:
         actions = super().execute(state, environment)
-        event = CompensationEvent(environment.group, state.reference.process_id, state.reference.process_instance_id)
+        event = CompensationEvent(environment.group, state.node_ref.process_id, state.node_ref.process_instance_id)
         return state, [EventAction(self.id, event)] + actions
 
     def __repr__(self):
