@@ -71,7 +71,7 @@ class CallActivity(BpmnNode):
             return state, [CompleteAction(self.id)] + actions
 
         incoming_state = map_state(self.incoming_state)
-        task_reference = NodeRef(environment.group, state.reference.process_id, self.id)
+        task_reference = NodeRef(environment.group, state.node_ref.process_id, self.id)
 
         return state, [
             QueueAction(self.id, save_state=False),
